..
    This file is part of Invenio.
    Copyright (C) 2017-2018 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

.. _translation-guide:

Translation guide
=================

Invenio has been translated to more than 25 languages.

Transifex
---------

All Invenio internationalisation and localisation efforts are happening on the
`Transifex <https://www.transifex.com/>`_ collaborative localisation platform.

You can start by exploring `Invenio project dashboard
<https://www.transifex.com/inveniosoftware/invenio/dashboard/Invenio>`_ on
Transifex.

Invenio project consists of many resource files which can be categorised as
follows:

- ``invenio-maint10-messages`` contains phrases for Invenio 1.0 legacy release series
- ``invenio-maint11-messages`` contains phrases for Invenio 1.1 legacy release series
- ``invenio-maint12-messages`` contains phrases for Invenio 1.2 legacy release series
- ``invenio-xxx-messages`` contains phrases for Invenio 3.0 ``invenio-xxx`` module

We follow the usual Transifex localisation workflow that is `extensively
documented <https://docs.transifex.com/>`_.

Translators
-----------

All contributions with translating phrases or with reviewing translations are
very appreciated!

Please read `Getting started as a translator
<https://docs.transifex.com/getting-started/translators>`_ and join Invenio
project on Transifex.

Developers
----------

Please see dedicated `invenio-i18n documentation
<https://invenio-i18n.readthedocs.io/en/latest/usage.html>`_.
